@@ -20,15 +20,16 @@
 
 #define P(F, O) { FILE* fp = fopen(F, "a"); fprintf(fp, O); fprintf(fp, "\n"); fclose(fp); }
 
-void mygetcwd(SPACE char* result);                  // cwdを返す
-void parentname(SPACE char* result, char* path);    // 親ディレクトリを返す
-void extname(SPACE char* result, char* name);       // 拡張子を返す
-void noextname(SPACE char* result, char* name);     // 拡張子以外のファイル名を返す
-
-char* mystrcasestr(const char *haystack, const char *needle); // 部分文字列を返す
+void mygetcwd(SPACE char* result, int result_size);                  // cwdを返す
+void parentname(SPACE char* result, int result_size, char* path);    // 親ディレクトリを返す
+void extname(SPACE char* result, int result_size, char* name);       // 拡張子を返す
+void noextname(SPACE char* result, int result_size, char* name);     // 拡張子以外のファイル名を返す
 void mystrtolower(char* result);           // 文字列を小文字にする
 
-int correct_path(char* current_path, char* path, char* path2);
+int correct_path(char* current_path, char* path, char* path2, int path2_size);                                        // パスの(えせ)正規化
+
+char* mystrcasestr(const char *haystack, const char *needle); // 部分文字列を返す
+
 
 #endif
 
