@@ -178,7 +178,7 @@ BOOL string_chomp(string_obj* str);
 void string_ponch(string_obj* str);
     // ԥɤդ(\n)
 
-void string_pomch(string_obj* str);
+void string_pomch(string_obj* str, enum eLineField lf);
     // ԥɤդ(ԥɤΤޤ)
 
 BOOL xclose(int fd);
