@@ -270,7 +270,7 @@ void string_ponch(string_obj* str)
 }
 
 // 改行コードを付ける(改行コードそのまま)
-void string_pomch(string_obj* str)
+void string_pomch(string_obj* str, enum eLineField lf)
 {
     char* s = string_c_str(str);
     const int len = strlen(s);
@@ -280,10 +280,10 @@ void string_pomch(string_obj* str)
     else if(len >= 1 && (s[len-1] == '\r' || s[len-1] == '\n')) {
     }
     else {
-        if(gLineField == kCR) {
+        if(lf == kCR) {
             string_push_back2(str, '\r');
         }
-        else if(gLineField == kCRLF) {
+        else if(lf == kCRLF) {
             string_push_back(str, "\r\n");
         }
         else {
@@ -2671,7 +2671,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
 
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.2.1", 1);
+    setenv("SAPHIRE_VERSION", "1.2.3", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
